summaryrefslogtreecommitdiff
path: root/client/src/leap/soledad/client/http_target/support.py
diff options
context:
space:
mode:
Diffstat (limited to 'client/src/leap/soledad/client/http_target/support.py')
-rw-r--r--client/src/leap/soledad/client/http_target/support.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/client/src/leap/soledad/client/http_target/support.py b/client/src/leap/soledad/client/http_target/support.py
index 5daabb61..44cd7089 100644
--- a/client/src/leap/soledad/client/http_target/support.py
+++ b/client/src/leap/soledad/client/http_target/support.py
@@ -167,12 +167,12 @@ class RequestBody(object):
self.entries.append(entry)
return len(entry)
- def remove(self, number=1):
+ def pop(self, number=1):
"""
Removes an amount of entries and returns it formatted and ready
to be sent.
:param number: number of entries to remove and format
:type number: int
:return: formatted body ready to be sent
@@ -167,12 +167,12 @@ class RequestBody(object):
Removes an amount of entries and returns it formatted and ready
to be sent.
- :param number: number of entries to remove and format
+ :param number: number of entries to pop and format
:type number: int
:return: formatted body ready to be sent